@@ -75,7 +75,7 @@ void MainWindow::getMetaData()
             QString title = mediaPlayer->extendedMetaData("title").toString();
             appendCronology(title);
 
-            ui->playingLabel->setText(QString("<b>Playing:</b> %1").arg(title));
+            ui->playingLabel->setText(QString(tr("<b>Playing:</b> %1")).arg(title));
 
             labelBox.setText("Playing '" + extn_metadata_value.toString() + "'");
             infoBox.show();
@@ -98,7 +98,7 @@ void MainWindow::getMetaData()
         {
             QString string = mediaPlayer->extendedMetaData("genre").toString();
 
-            ui->genreLabel->setText(QString("<b>Genre:</b> %1").arg(string));
+            ui->genreLabel->setText(QString(tr("<b>Genre:</b> %1")).arg(string));
 
         }
 
@@ -106,7 +106,7 @@ void MainWindow::getMetaData()
         {
             QString string = mediaPlayer->extendedMetaData("bitrate").toString();
 
-            ui->bitrateLabel->setText(QString("<b>Bitrate:</b> %1").arg(string));
+            ui->bitrateLabel->setText(QString(tr("<b>Bitrate:</b> %1")).arg(string));
 
         }
 
@@ -114,7 +114,7 @@ void MainWindow::getMetaData()
         {
             QString string = mediaPlayer->extendedMetaData("location").toString();
 
-            ui->locationLabel->setText(QString("<b>Location:</b> %1").arg(string));
+            ui->locationLabel->setText(QString(tr("<b>Location:</b> %1")).arg(string));
 
         }
 
@@ -122,7 +122,7 @@ void MainWindow::getMetaData()
         {
             QString string = mediaPlayer->extendedMetaData("audio-codec").toString();
 
-            ui->audiocodecLabel->setText(QString("<b>Audio codec:</b> %1").arg(string));
+            ui->audiocodecLabel->setText(QString(tr("<b>Audio codec:</b> %1")).arg(string));
 
         }
     }
@@ -172,7 +172,7 @@ void MainWindow::onRequestFinished(QNetworkReply *reply)
     this->loadImage(albumArtUrl);
 
     if (lyrics.size()>0) ui->lyricsLabel->setText(lyrics);
-    else ui->lyricsLabel->setText("No lyric found");
+    else ui->lyricsLabel->setText(tr("No lyric found"));
 }
 
 void MainWindow::on_playingNowButton_clicked()
@@ -191,7 +191,7 @@ void MainWindow::updateLyrics()
     QString getUrl = url.arg(ui->titleLineEdit->text(), ui->artistLineEdit->text());
     nam->get(QNetworkRequest(getUrl));
 
-    ui->lyricsLabel->setText("Loading lyrics...");
+    ui->lyricsLabel->setText(tr("Loading lyrics..."));
     ui->albumImageLabel->setPixmap(QPixmap(":/icons/globe.png"));
 }
 
@@ -255,7 +255,7 @@ void MainWindow::on_stopButton_clicked()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About"),
-                        tr("<h2>Internet Radio Player 0.0.6</h2>"
+                        tr("<h2>Internet Radio Player 0.0.7</h2>"
                            "<p>"
                            "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"
                            "<p><a href=\"http://code-tinkering.blogspot.com/\">My personal blog.</a>"
@@ -266,13 +266,13 @@ void MainWindow::on_addStationButton_clicked()
 {
     bool ok1, ok2, ok3, ok4;
     QString name, url, genre, country;
-    name = QInputDialog::getText(this, "New Station", "Insert Name: ", QLineEdit::Normal, QString(), &ok1, 0);
+    name = QInputDialog::getText(this, tr("New Station"), tr("Insert Name: "), QLineEdit::Normal, QString(), &ok1, 0);
     if ( !ok1 ) return;
-    url = QInputDialog::getText(this, "New Station", "Insert Url: ", QLineEdit::Normal, QString(), &ok2, 0);
+    url = QInputDialog::getText(this, tr("New Station"), tr("Insert Url: "), QLineEdit::Normal, QString(), &ok2, 0);
     if (!ok2 ) return;
-    genre = QInputDialog::getText(this, "New Station", "Insert Genre: ", QLineEdit::Normal, QString(), &ok3, 0);
+    genre = QInputDialog::getText(this, tr("New Station"), tr("Insert Genre: "), QLineEdit::Normal, QString(), &ok3, 0);
     if (!ok3 ) return;
-    country = QInputDialog::getText(this, "New Station", "Insert Country: ", QLineEdit::Normal, QString(), &ok4, 0);
+    country = QInputDialog::getText(this, tr("New Station"), tr("Insert Country: "), QLineEdit::Normal, QString(), &ok4, 0);
     if (!ok4 ) return;
 
     stationsDb.insertStation(name, url, genre, country);
@@ -294,13 +294,13 @@ void MainWindow::on_editStationButton_clicked()
 
     bool ok1, ok2, ok3, ok4;
     QString name, url, genre, country;
-    name = QInputDialog::getText(this, "Edit Station", "Insert Name: ", QLineEdit::Normal, currentName, &ok1, 0);
+    name = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Name: "), QLineEdit::Normal, currentName, &ok1, 0);
     if ( !ok1 ) return;
-    url = QInputDialog::getText(this, "Edit Station", "Insert Url: ", QLineEdit::Normal, currentUrl, &ok2, 0);
+    url = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Url: "), QLineEdit::Normal, currentUrl, &ok2, 0);
     if (!ok2 ) return;
-    genre = QInputDialog::getText(this, "Edit Station", "Insert Genre: ", QLineEdit::Normal, QString(), &ok3, 0);
+    genre = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Genre: "), QLineEdit::Normal, QString(), &ok3, 0);
     if (!ok3 ) return;
-    country = QInputDialog::getText(this, "Edit Station", "Insert Country: ", QLineEdit::Normal, QString(), &ok4, 0);
+    country = QInputDialog::getText(this, tr("Edit Station"), tr("Insert Country: "), QLineEdit::Normal, QString(), &ok4, 0);
     if (!ok4 ) return;
 
     stationsDb.updateStation(currentUrl, name, url, genre, country);
@@ -379,6 +379,7 @@ void MainWindow::saveStationsList()
 
 void MainWindow::on_actionToggleFullscreen_triggered()
 {
+    qDebug()<<"Buffer: "<<mediaPlayer->bufferStatus();
     bool isFullscreen = ui->actionToggleFullscreen->property("isFullScreen").toBool();
 
     if (isFullscreen)
@@ -585,3 +586,6 @@ void MainWindow::toggleButtonPressed()
     }
 
 }
+
+
+
